@@ -1,6 +1,11 @@
 # Functions used by widget tests.
 
-import imp
+import importlib
+# AH: fix for Python >=3.9
+try:
+    x = importlib.util
+except AttributeError:
+    import importlib.util
 import os
 import re
 import string
@@ -11,12 +16,15 @@ import tkinter
 import _tkinter
 import inspect
 
-if tkinter.TkVersion >= 8.4:
+def afterTk85():
+    return tkinter.TkVersion > 8.5
+
+if tkinter.TkVersion in (8.4, 8.5):
     refcountafterdestroy = 7
 else:
     refcountafterdestroy = 6
 
-script_name = imp.find_module(__name__)[1]
+script_name = importlib.util.find_spec(__name__).origin
 if not os.path.isabs(script_name):
     script_name = os.path.join(os.getcwd(), script_name)
 
@@ -35,6 +43,11 @@ package_dir = os.path.dirname(package_dir)
 sys.path[:0] = [package_dir]
 
 import Pmw
+
+#disable Tkinter 85 compatibility if TKinter > 8.5
+#if tkinter.TkVersion > 8.5:
+#    Pmw.setTkinter85Compatible(False)
+
 # Need to import TestVersion, rather than do its work here, since
 # __name__ will be known there.
 import TestVersion
@@ -101,9 +114,6 @@ def initialise():
 
         _initialised = 1
 
-def enableBlt():
-    Pmw.Blt.setBltDisable(root, False)
-
 def haveBlt():
     return Pmw.Blt.haveblt(root)
 
@@ -224,16 +234,16 @@ def _print_results(result, expected, description):
                 ok = (str(stringvar) == result.string)
 
     if not ok or _verbose > 0:
-        print(('====', description))
+        print('==== ' + description)
         if not ok or _verbose > 1:
             print('==== result was:')
-            print((result, type(result)))
+            print(str(result) + ' ' + str(type(result)))
     if ok:
         if _verbose > 1:
             print('++++ PASSED')
     else:
         print('---- result should have been:')
-        print((expected, type(expected)))
+        print(str(expected) + ' ' + str(type(expected)))
         if _printTraceback:
             traceback.print_exc()
         print('---- FAILED')
@@ -241,12 +251,12 @@ def _print_results(result, expected, description):
 
 def _destroyToplevel(top, title):
     if _verbose > 0:
-        print(('==== destruction of Toplevel for', title))
+        print('==== destruction of Toplevel for ' + title)
     top.destroy()
 
 def _Toplevel(title):
     if _verbose > 0:
-        print(('==== construction of Toplevel for', title))
+        print('==== construction of Toplevel for ' + title)
     top = tkinter.Toplevel()
     top.geometry('+100+100')
     top.title(title)
@@ -254,9 +264,7 @@ def _Toplevel(title):
 
 def _constructor(isWidget, top, classCmd, kw):
     if _verbose > 0:
-        print(('====', classCmd.__class__.__name__, 'construction'))
-    #print(isWidget, top, classCmd, kw)
-    #print(isWidget)
+        print('==== ' + classCmd.__class__.__name__ + ' construction')
     if isWidget:
         if (type(classCmd) != type):
             classCmdType = type(classCmd)
@@ -268,7 +276,7 @@ def _constructor(isWidget, top, classCmd, kw):
             try:
                 w = classCmdType(*(top,), **kw)
             except:
-                print(('Could not construct', classCmd.__class__.__name__))
+                print('Could not construct ' + classCmd.__class__.__name__)
                 traceback.print_exc()
                 print('Can not continue')
                 print('Bye')
@@ -290,13 +298,13 @@ def _constructor(isWidget, top, classCmd, kw):
                         w.configure(*(), **{option : value})
                         newvalue = w.cget(option)
                         if newvalue != value:
-                            print(('====', classCmd.__class__.__name__, 'widget', \
-                              '\'' + option + '\'', 'option'))
+                            print('==== ' + classCmd.__class__.__name__ + ' widget ' + \
+                              '\'' + option + '\'' + ' option')
                             print('---- setting option returns different value')
                             print('==== new value was:')
-                            print((newvalue, type(newvalue)))
+                            print(str(newvalue) + ' ' + str(type(newvalue)))
                             print('---- set value was:')
-                            print((value, type(value)))
+                            print(str(value) + ' ' + str(type(value)))
                             print('---- FAILED')
                             print()
                 else:
@@ -318,24 +326,24 @@ def _constructor(isWidget, top, classCmd, kw):
                                     not hasattr(_tkinter, 'Tcl_Obj') and
                                       newvalue != value
                                 ):
-                                    print(('====', classCmd.__class__.__name__, 'widget', \
-                                      '\'' + option + '\'', 'option'))
+                                    print('==== ' + classCmd.__class__.__name__ + ' widget ' + \
+                                      '\'' + option + '\'' + ' option')
                                     print('---- setting option returns different value')
                                     print('==== new value was:')
-                                    print((repr(newvalue), type(newvalue)))
+                                    print(repr(newvalue) + ' ' + str(type(newvalue)))
                                     print('---- set value was:')
-                                    print((repr(value), type(value)))
+                                    print(repr(value) + ' ' + str(type(value)))
                                     print('---- FAILED')
                                     print()
                             except:
-                                print(('====', classCmd.__class__.__name__, 'widget', \
-                                  '\'' + option + '\'', 'option'))
+                                print('==== ' + classCmd.__class__.__name__ + ' widget ' + \
+                                  '\'' + option + '\'' + ' option')
                                 print('---- could not set option')
                                 print('---- FAILED')
                                 print()
                     except KeyError:
-                        print(('====', classCmd.__class__.__name__, 'widget', \
-                            '\'' + option + '\'', 'option'))
+                        print('==== ' + classCmd.__class__.__name__ + ' widget ' + \
+                            '\'' + option + '\'' + ' option')
                         print('---- unknown option')
                         print('---- FAILED')
                         print()
@@ -349,7 +357,7 @@ def _constructor(isWidget, top, classCmd, kw):
 
 def _destructor(widget, isWidget):
     if _verbose > 0:
-        print(('====', widget.__class__.__name__, 'destruction'))
+        print('==== ' + widget.__class__.__name__ + ' destruction')
     if isWidget:
         if dont_even_try:
             widget.destroy()
@@ -358,12 +366,12 @@ def _destructor(widget, isWidget):
                 widget.destroy()
                 ref = sys.getrefcount(widget)
                 if ref != refcountafterdestroy:
-                    print(('====', widget.__class__.__name__, 'destructor'))
-                    print(('---- refcount', ref, 'not zero after destruction'))
+                    print('==== ' + widget.__class__.__name__ + ' destructor')
+                    print('---- refcount ' + str(ref) + ' not zero after destruction')
                     print('---- FAILED')
                     print()
             except:
-                print(('Could not destroy', widget.__class__.__name__))
+                print('Could not destroy ' + widget.__class__.__name__)
                 traceback.print_exc()
                 print('Can not continue')
                 print('Bye')
@@ -428,8 +436,6 @@ def _destructor(widget, isWidget):
 # )
 
 def _runTest(top, w, allTestData, index0, index1, index2):
-    #print(index0)
-    #print(index0, index1, index2)
     if index0 >= len(allTestData):
         root.quit()
         return
@@ -440,7 +446,6 @@ def _runTest(top, w, allTestData, index0, index1, index2):
         isToplevel = hasattr(classCmd, 'userdeletefunc')
     isWidget = hasattr(classCmd, 'cget')
     title = classCmd.__class__.__name__
-    #print(title)
 
     if index1 == -1:
         if isToplevel:
@@ -457,7 +462,6 @@ def _runTest(top, w, allTestData, index0, index1, index2):
         index0 = index0 + 1
     else:
         methodTests, kw = fileTests[index1]
-        #print(isWidget, top, classCmd, kw)
         if index2 == -1:
             w = _constructor(isWidget, top, classCmd, kw)
             if w is None:
@@ -475,8 +479,6 @@ def _runTest(top, w, allTestData, index0, index1, index2):
             index1 = index1 + 1
         else:
             methodTestData = methodTests[index2]
-            #Transition to Python3
-            #if type(methodTestData[0]) == bytes:
             if type(methodTestData[0]) is str:
                 _configureTest(w, methodTestData)
             else:
@@ -535,13 +537,15 @@ def _methodTest(w, testData):
     if func is num_options:
         args = (w,) + args
     origArgs = args
-    #if type(func) == types.MethodType and func.__self__ is None:
-    #    args = (w,) + args
+
+    # If func is an object method, prepend w as the 'self' argument:
+    # was: if type(func) == types.MethodType and func.__self__ is None:
     try:
         getattr(w, func.__name__)
         args = (w,) + args
     except AttributeError:
         pass
+
     if dont_even_try:
         print(func)
     else:
